@@ -92,7 +92,7 @@ function sentryRefresh(){
           // $('#message_list').each(function(){
           //               $(this).removeClass('fresh');
           //           })
-          if (groups) {
+          if (groups.length) {
               $('#no_messages').remove();
           }
           for (var i=groups.length-1, el, row; (el=groups[i]); i--) {
