@@ -5,6 +5,6 @@ admin.autodiscover()
 
 urlpatterns = patterns('',
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^$', 'sentry.tests.views.raise_exc', name='sentry-raise-exc'),
+    url(r'^trigger-500$', 'sentry.tests.views.raise_exc', name='sentry-raise-exc'),
     url(r'', include('sentry.urls')),
 )
\ No newline at end of file
